@@ -16,9 +16,13 @@ class TaskContractor(Contractor):
     """A contractor to handle task related ones."""
 
     _URL = 'http://federated-service:9080/fed-service/api/v2'
+    _REPORT_PROGRESS_URL = f'{_URL}/federated/task/progress'
 
     _TASK_TYPE = 1  # manual
 
+    _ENTRY_PY = 'py'
+    _ENTRY_PICKLE = 'pickle'
+
     def __init__(self, task_id: str) -> None:
         super().__init__()
         self.task_id = task_id
@@ -81,6 +85,7 @@ class TaskContractor(Contractor):
             'task_type': self._TASK_TYPE
         }
         post_url = f'{self._URL}/task/nodelist'
+        logger.debug(f'query nodes contract content: {post_data}')
         resp = requests.post(url=post_url, json=post_data, headers=self._HEADERS)
         resp_data = self._validate_response(resp=resp)
         records: list[dict] = resp_data.get('records')
@@ -144,8 +149,6 @@ class TaskContractor(Contractor):
         if isinstance(fp, str):
             post_data['file_path'] = fp
             resp = requests.post(url=post_url, params=post_data, headers=headers)
-            logger.error(f'{post_data=}')
-            logger.error(f'{resp=}')
         else:
             post_data['file_path'] = upload_name
             fp.seek(0)
@@ -175,7 +178,65 @@ class TaskContractor(Contractor):
             'task_id': self.task_id,
             'progress_number': percent
         }
-        post_url = f'{self._URL}/automl/task/progress'
+        post_url = self._REPORT_PROGRESS_URL
+        resp = requests.post(url=post_url, json=post_data, headers=self._HEADERS)
+        self._validate_response(resp=resp)
+
+    def _submit_data_checker(self, resource_url: str, entry_type: str):
+        """Submit a data checker implementation to the task manager."""
+        assert (
+            resource_url and isinstance(resource_url, str)
+        ), f'Invalid resource url: `{resource_url}`.'
+        assert (
+            entry_type and isinstance(entry_type, str)
+            and entry_type in (self._ENTRY_PICKLE, self._ENTRY_PY)
+        ), f'Invalid entry type: `{entry_type}`.'
+
+        if is_mock_mode():
+            self._submit_data_checker_mock(resource_url=resource_url, entry_type=entry_type)
+        else:
+            self._submit_data_checker_normal(resource_url=resource_url, entry_type=entry_type)
+
+    def _submit_data_checker_mock(self, resource_url: str, entry_type: str):
+        pass
+
+    def _submit_data_checker_normal(self, resource_url: str, entry_type: str):
+        post_data = {
+            'task_id': self.task_id,
+            'f_url': resource_url,
+            'file_type': entry_type
+        }
+        post_url = f'{self._URL}/federated/task/verify/upload'
+        logger.debug(f'submit data checker implementation: {post_data}')
+        resp = requests.post(url=post_url, json=post_data, headers=self._HEADERS)
+        self._validate_response(resp=resp)
+
+    def _submit_scheduler(self, resource_url: str, entry_type: str):
+        """Submit a scheduler implementation to the task manager."""
+        assert (
+            resource_url and isinstance(resource_url, str)
+        ), f'Invalid resource url: `{resource_url}`.'
+        assert (
+            entry_type and isinstance(entry_type, str)
+            and entry_type in (self._ENTRY_PICKLE, self._ENTRY_PY)
+        ), f'Invalid entry type: `{entry_type}`.'
+
+        if is_mock_mode():
+            self._submit_scheduler_mock(resource_url=resource_url, entry_type=entry_type)
+        else:
+            self._submit_scheduler_normal(resource_url=resource_url, entry_type=entry_type)
+
+    def _submit_scheduler_mock(self, resource_url: str, entry_type: str):
+        pass
+
+    def _submit_scheduler_normal(self, resource_url: str, entry_type: str):
+        post_data = {
+            'task_id': self.task_id,
+            'f_url': resource_url,
+            'file_type': entry_type
+        }
+        post_url = f'{self._URL}/federated/task/train/upload'
+        logger.debug(f'submit data checker implementation: {post_data}')
         resp = requests.post(url=post_url, json=post_data, headers=self._HEADERS)
         self._validate_response(resp=resp)
 
@@ -184,3 +245,4 @@ class AutoTaskContractor(TaskContractor):
     """AutoML version TaskContractor."""
 
     _TASK_TYPE = 2  # auto_ml
+    _REPORT_PROGRESS_URL = f'{TaskContractor._URL}/automl/task/progress'
