@@ -14,7 +14,7 @@ from typing import Dict, List, Optional, Union, overload
 import requests
 from requests import Response
 
-from .. import is_mock_mode, logger, mock_node_id
+from .. import is_mock_mode, logger, mock_node_id, mock_nodes
 from ..mock import _get_mock_contract, _put_mock_contract
 from ..utils import retry
 from .common import (ContractEvent, ContractEventFactory, ContractException,
@@ -304,11 +304,24 @@ class TaskMessageContractor(Contractor):
                            event: ContractEvent,
                            message_title: str = _TASK_INSIDE) -> str:
         content = json.dumps(event.event_to_contract(), ensure_ascii=False)
+        if targets == self.EVERYONE:
+            targets = mock_nodes()
+            if not targets:
+                raise ContractException('Can not obtain Node ID list of current task.')
+        contract_content = {
+            "targets": targets,
+            "message_title": message_title,
+            "content": content,
+            "channel": self._CHANNEL,
+            "task_id": self.task_id
+        }
+        logger.debug(f'try to push a contract in mock context: {contract_content}')
         return _put_mock_contract(targets=targets,
                                   message_title=message_title,
                                   content=content,
                                   message_time=int(datetime.now().timestamp()),
-                                  channel=self._CHANNEL)
+                                  channel=self._CHANNEL,
+                                  task_id=self.task_id)
 
     def _new_contract_normal(self,
                              targets: List[str],
@@ -343,8 +356,13 @@ class TaskMessageContractor(Contractor):
             return self._pop_contract_normal()
 
     def _pop_contract_mock(self) -> Optional[dict]:
-        content = _get_mock_contract(node_id=mock_node_id(), channel=self._CHANNEL)
-        return json.loads(content) if content is not None else None
+        content = _get_mock_contract(node_id=mock_node_id(),
+                                     channel=self._CHANNEL,
+                                     task_id=self.task_id)
+        if content is None:
+            return None
+        logger.debug(f'popped up a contract in mock context: {content}')
+        return json.loads(content)
 
     def _pop_contract_normal(self) -> Optional[dict]:
         post_data = {
@@ -472,7 +490,6 @@ class TaskMessageContractor(Contractor):
                     logger.warn(f'failed to parse a contract to an event: {_contract}')
             else:
                 time.sleep(1)
-            continue
 
     @retry()
     def query_address(self, target: str) -> Optional[str]:
