@@ -19,9 +19,8 @@ from alphafed.data_channel.shared_file_data_channel import \
 from alphafed.scheduler import Scheduler
 
 from .contractor import (CheckinEvent, CheckinResponseEvent, CloseRoundEvent,
-                         DistributeParametersEvent, ReadyForAggregationEvent,
-                         SimpleFedAvgContractor, StartRoundEvent,
-                         UploadTrainingResultsEvent)
+                         ReadyForAggregationEvent, SimpleFedAvgContractor,
+                         StartRoundEvent)
 
 
 class SimpleFedAvgScheduler(Scheduler, metaclass=ABCMeta):
@@ -295,9 +294,9 @@ class SimpleFedAvgScheduler(Scheduler, metaclass=ABCMeta):
         buffer = io.BytesIO()
         torch.save(self.state_dict(), buffer)
         self.push_log('Distributing parameters ...')
-        accept_list = self.data_channel.send_stream(source=self.id,
-                                                    target=self._participants,
-                                                    data_stream=buffer.getvalue())
+        accept_list = self.data_channel.batch_send_stream(source=self.id,
+                                                          target=self._participants,
+                                                          data_stream=buffer.getvalue())
         self.push_log(f'Successfully distributed parameters to: {accept_list}')
         if len(self._participants) != len(accept_list):
             reject_list = [_target for _target in self._participants
@@ -339,18 +338,18 @@ class SimpleFedAvgScheduler(Scheduler, metaclass=ABCMeta):
                 _param.zero_()
 
         self.push_log('Waiting for training results ...')
-        for _event in self.contractor.contract_events():
-            if isinstance(_event, UploadTrainingResultsEvent):
-                training_result = self.data_channel.receive_stream(apply_event=_event,
-                                                                   receiver=self.id)
-                buffer = io.BytesIO(training_result)
-                _new_state_dict = torch.load(buffer)
-                for _key in accum_result.keys():
-                    accum_result[_key].add_(_new_state_dict[_key])
-                result_count += 1
-                self.push_log(f'Received calculation results from ID: {_event.source}')
-                if result_count >= len(self._participants):
-                    return accum_result, result_count
+        training_results = self.data_channel.batch_receive_stream(
+            receiver=self.id,
+            source_list=self._participants
+        )
+        for _source, _result in training_results.items():
+            buffer = io.BytesIO(_result)
+            _new_state_dict = torch.load(buffer)
+            for _key in accum_result.keys():
+                accum_result[_key].add_(_new_state_dict[_key])
+            result_count += 1
+            self.push_log(f'Received calculation results from ID: {_source}')
+        return accum_result, result_count
 
     def _close_round(self):
         """Close current round when finished."""
@@ -373,7 +372,7 @@ class SimpleFedAvgScheduler(Scheduler, metaclass=ABCMeta):
         torch.save(self.state_dict(), buffer)
         self.push_log('Pushing local update to the aggregator ...')
         self.data_channel.send_stream(source=self.id,
-                                      target=[self._aggregator],
+                                      target=self._aggregator,
                                       data_stream=buffer.getvalue())
         self.push_log('Successfully pushed local update to the aggregator.')
         self._switch_status(self._CLOSING_ROUND)
@@ -392,15 +391,13 @@ class SimpleFedAvgScheduler(Scheduler, metaclass=ABCMeta):
     def _wait_for_updating_model(self):
         """Wait for receiving latest parameters from aggregator."""
         self.push_log('Waiting for receiving latest parameters from the aggregator ...')
-        for _event in self.contractor.contract_events():
-            if isinstance(_event, DistributeParametersEvent):
-                parameters = self.data_channel.receive_stream(apply_event=_event,
-                                                              receiver=self.id)
-                buffer = io.BytesIO(parameters)
-                new_state_dict = torch.load(buffer)
-                self.load_state_dict(new_state_dict)
-                self.push_log('Successfully received latest parameters.')
-                return
+        _, parameters = self.data_channel.receive_stream(receiver=self.id,
+                                                         source=self._aggregator)
+        buffer = io.BytesIO(parameters)
+        new_state_dict = torch.load(buffer)
+        self.load_state_dict(new_state_dict)
+        self.push_log('Successfully received latest parameters.')
+        return
 
     def _wait_for_uploading_model(self):
         """Wait for uploading trained parameters to aggregator."""
