@@ -61,7 +61,7 @@ class SimpleTaskScheduler(SimpleFedAvgScheduler):
     def build_train_dataloader(self) -> DataLoader:
         return DataLoader(
             datasets.MNIST(
-                get_dataset_dir(),
+                get_dataset_dir(self.task_id),
                 train=True,
                 download=True,
                 transform=transforms.Compose([
@@ -76,7 +76,7 @@ class SimpleTaskScheduler(SimpleFedAvgScheduler):
     def build_test_dataloader(self) -> DataLoader:
         return DataLoader(
             datasets.MNIST(
-                get_dataset_dir(),
+                get_dataset_dir(self.task_id),
                 train=False,
                 download=True,
                 transform=transforms.Compose([
@@ -140,4 +140,4 @@ scheduler = SimpleTaskScheduler(clients=2,
                                 batch_size=128,
                                 learning_rate=0.01,
                                 momentum=0.9)
-scheduler.launch_task(task_id='task_id')
+scheduler.submit(task_id='task_id')
