@@ -34,7 +34,6 @@ from alphafed.auto_ml.auto_model import (AutoFedAvgModel, AutoFedAvgScheduler,
                                          MandatoryConfig, Preprocessor)
 from alphafed.auto_ml.cvat.annotation import ImageAnnotationUtils
 from alphafed.auto_ml.exceptions import AutoModelError, ConfigError
-from alphafed.scheduler import register_metrics
 
 
 @dataclass
@@ -599,8 +598,6 @@ class ResNetFedAvgScheduler(AutoFedAvgScheduler):
 
     def __init__(self,
                  auto_proxy: AutoResNetFedAvg,
-                 min_clients: int,
-                 max_clients: int,
                  max_rounds: int = 0,
                  merge_epochs: int = 1,
                  calculation_timeout: int = 300,
@@ -608,8 +605,6 @@ class ResNetFedAvgScheduler(AutoFedAvgScheduler):
                  log_rounds: int = 0,
                  involve_aggregator: bool = False):
         super().__init__(auto_proxy=auto_proxy,
-                         min_clients=min_clients,
-                         max_clients=max_clients,
                          max_rounds=max_rounds,
                          merge_epochs=merge_epochs,
                          calculation_timeout=calculation_timeout,
@@ -636,13 +631,8 @@ class ResNetFedAvgScheduler(AutoFedAvgScheduler):
     def train_an_epoch(self):
         self.auto_proxy.train_an_epoch()
 
-    @register_metrics(name='test_results', keys=['average_loss', 'correct_rate'])
-    def test(self):
-        avg_loss, correct_rate = self.auto_proxy.run_test()
-        self.get_metrics('test_results').append_metrics_item({
-            'average_loss': avg_loss,
-            'correct_rate': correct_rate
-        })
+    def run_test(self):
+        self.auto_proxy.run_test()
 
     def is_task_finished(self) -> bool:
         """Decide if stop training.
