@@ -2,7 +2,6 @@
 
 import os
 from time import time
-from typing import Dict
 
 import torch
 import torch.nn as nn
@@ -11,7 +10,7 @@ import torchvision
 from torch import optim
 from torch.utils.data import DataLoader
 
-from ... import logger
+from ... import get_dataset_dir, logger
 from ...fed_avg import FedAvgScheduler, FedSGDScheduler, SecureFedAvgScheduler
 from ...fed_avg.dp_fed_avg import DPFedAvgScheduler
 from . import DEV_TASK_ID
@@ -49,26 +48,18 @@ class ConvNet(nn.Module):
 class DemoAvg(FedAvgScheduler):
 
     def __init__(self,
-                 min_clients: int,
-                 max_clients: int,
-                 name: str = None,
                  max_rounds: int = 0,
                  merge_epochs: int = 1,
                  calculation_timeout: int = 300,
                  log_rounds: int = 0,
-                 is_centralized: bool = True,
                  involve_aggregator: bool = False,
-                 batch_size: int = 64,
+                 batch_size: int = 128,
                  learning_rate: float = 0.01,
-                 momentum: float = 0.5) -> None:
-        super().__init__(min_clients=min_clients,
-                         max_clients=max_clients,
-                         name=name,
-                         max_rounds=max_rounds,
+                 momentum: float = 0.9) -> None:
+        super().__init__(max_rounds=max_rounds,
                          merge_epochs=merge_epochs,
                          calculation_timeout=calculation_timeout,
                          log_rounds=log_rounds,
-                         is_centralized=is_centralized,
                          involve_aggregator=involve_aggregator)
         self.batch_size = batch_size
         self.learning_rate = learning_rate
@@ -84,14 +75,14 @@ class DemoAvg(FedAvgScheduler):
 
     def build_optimizer(self, model: nn.Module) -> optim.Optimizer:
         assert self.model, 'must initialize model first'
-        return optim.SGD(self.model.parameters(),
+        return optim.SGD(model.parameters(),
                          lr=self.learning_rate,
                          momentum=self.momentum)
 
     def build_train_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=True,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -106,7 +97,7 @@ class DemoAvg(FedAvgScheduler):
     def build_test_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=False,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -118,12 +109,6 @@ class DemoAvg(FedAvgScheduler):
             shuffle=False
         )
 
-    def state_dict(self) -> Dict[str, torch.Tensor]:
-        return self.model.state_dict()
-
-    def load_state_dict(self, state_dict: Dict[str, torch.Tensor]):
-        self.model.load_state_dict(state_dict)
-
     def validate_context(self):
         super().validate_context()
         assert self.train_loader and len(self.train_loader) > 0, 'failed to load train data'
@@ -143,7 +128,7 @@ class DemoAvg(FedAvgScheduler):
             loss.backward()
             self.optimizer.step()
 
-    def test(self):
+    def run_test(self):
         start = time()
         self.model.eval()
         test_loss = 0
@@ -177,20 +162,14 @@ class DemoAvg(FedAvgScheduler):
 class DemoSGD(FedSGDScheduler):
 
     def __init__(self,
-                 min_clients: int,
-                 name: str = None,
                  max_rounds: int = 0,
                  calculation_timeout: int = 300,
                  log_rounds: int = 0,
-                 is_centralized: bool = True,
                  learning_rate: float = 0.01,
-                 momentum: float = 0.5) -> None:
-        super().__init__(min_clients=min_clients,
-                         name=name,
-                         max_rounds=max_rounds,
+                 momentum: float = 0.9) -> None:
+        super().__init__(max_rounds=max_rounds,
                          calculation_timeout=calculation_timeout,
-                         log_rounds=log_rounds,
-                         is_centralized=is_centralized)
+                         log_rounds=log_rounds)
         self.learning_rate = learning_rate
         self.momentum = momentum
 
@@ -204,13 +183,13 @@ class DemoSGD(FedSGDScheduler):
 
     def build_optimizer(self, model: nn.Module) -> optim.Optimizer:
         assert self.model, 'must initialize model first'
-        return optim.SGD(self.model.parameters(),
+        return optim.SGD(model.parameters(),
                          lr=self.learning_rate,
                          momentum=self.momentum)
 
     def build_train_dataloader(self) -> DataLoader:
         dataset = torchvision.datasets.MNIST(
-            os.path.join(self.name, 'data'),
+            get_dataset_dir(self.task_id),
             train=True,
             download=True,
             transform=torchvision.transforms.Compose([
@@ -223,7 +202,7 @@ class DemoSGD(FedSGDScheduler):
     def build_test_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=False,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -235,12 +214,6 @@ class DemoSGD(FedSGDScheduler):
             shuffle=False
         )
 
-    def state_dict(self) -> Dict[str, torch.Tensor]:
-        return self.model.state_dict()
-
-    def load_state_dict(self, state_dict: Dict[str, torch.Tensor]):
-        self.model.load_state_dict(state_dict)
-
     def validate_context(self):
         super().validate_context()
         assert self.train_loader and len(self.train_loader) > 0, 'failed to load train data'
@@ -260,7 +233,7 @@ class DemoSGD(FedSGDScheduler):
             loss.backward()
             self.optimizer.step()
 
-    def test(self):
+    def run_test(self):
         start = time()
         self.model.eval()
         test_loss = 0
@@ -295,24 +268,16 @@ class DemoSGD(FedSGDScheduler):
 class DemoSecure(SecureFedAvgScheduler):
 
     def __init__(self,
-                 min_clients: int,
-                 max_clients: int,
                  t: int,
-                 name: str = None,
                  max_rounds: int = 0,
                  merge_epochs: int = 1,
                  calculation_timeout: int = 300,
-                 log_rounds: int = 0,
-                 is_centralized: bool = True) -> None:
-        super().__init__(min_clients=min_clients,
-                         max_clients=max_clients,
-                         t=t,
-                         name=name,
+                 log_rounds: int = 0) -> None:
+        super().__init__(t=t,
                          max_rounds=max_rounds,
                          merge_epochs=merge_epochs,
                          calculation_timeout=calculation_timeout,
-                         log_rounds=log_rounds,
-                         is_centralized=is_centralized)
+                         log_rounds=log_rounds)
         self.batch_size = 64
         self.learning_rate = 0.01
         self.momentum = 0.5
@@ -326,14 +291,14 @@ class DemoSecure(SecureFedAvgScheduler):
         return model.to(self.device)
 
     def build_optimizer(self, model: nn.Module) -> optim.Optimizer:
-        return optim.SGD(self.model.parameters(),
+        return optim.SGD(model.parameters(),
                          lr=self.learning_rate,
                          momentum=self.momentum)
 
     def build_train_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=True,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -348,7 +313,7 @@ class DemoSecure(SecureFedAvgScheduler):
     def build_test_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=False,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -360,12 +325,6 @@ class DemoSecure(SecureFedAvgScheduler):
             shuffle=False
         )
 
-    def state_dict(self) -> Dict[str, torch.Tensor]:
-        return self.model.state_dict()
-
-    def load_state_dict(self, state_dict: Dict[str, torch.Tensor]):
-        self.model.load_state_dict(state_dict)
-
     def validate_context(self):
         super().validate_context()
         assert self.train_loader and len(self.train_loader) > 0, 'failed to load train data'
@@ -385,7 +344,7 @@ class DemoSecure(SecureFedAvgScheduler):
             loss.backward()
             self.optimizer.step()
 
-    def test(self):
+    def run_test(self):
         self.model.eval()
         test_loss = 0
         correct = 0
@@ -414,29 +373,23 @@ class DemoSecure(SecureFedAvgScheduler):
 class DemoDP(DPFedAvgScheduler):
 
     def __init__(self,
-                 min_clients: int,
                  w_cap: int,
                  q: float,
                  S: float,
                  z: float,
-                 name: str = None,
                  max_rounds: int = 0,
                  merge_epochs: int = 1,
                  calculation_timeout: int = 300,
                  log_rounds: int = 0,
-                 is_centralized: bool = True,
                  involve_aggregator: bool = False) -> None:
-        super().__init__(min_clients=min_clients,
-                         w_cap=w_cap,
+        super().__init__(w_cap=w_cap,
                          q=q,
                          S=S,
                          z=z,
-                         name=name,
                          max_rounds=max_rounds,
                          merge_epochs=merge_epochs,
                          calculation_timeout=calculation_timeout,
                          log_rounds=log_rounds,
-                         is_centralized=is_centralized,
                          involve_aggregator=involve_aggregator)
         self.batch_size = 64
         self.learning_rate = 0.01
@@ -451,14 +404,14 @@ class DemoDP(DPFedAvgScheduler):
         return model.to(self.device)
 
     def build_optimizer(self, model: nn.Module) -> optim.Optimizer:
-        return optim.SGD(self.model.parameters(),
+        return optim.SGD(model.parameters(),
                          lr=self.learning_rate,
                          momentum=self.momentum)
 
     def build_train_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=True,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -473,7 +426,7 @@ class DemoDP(DPFedAvgScheduler):
     def build_test_dataloader(self) -> DataLoader:
         return DataLoader(
             torchvision.datasets.MNIST(
-                os.path.join(self.name, 'data'),
+                get_dataset_dir(self.task_id),
                 train=False,
                 download=True,
                 transform=torchvision.transforms.Compose([
@@ -485,12 +438,6 @@ class DemoDP(DPFedAvgScheduler):
             shuffle=False
         )
 
-    def state_dict(self) -> Dict[str, torch.Tensor]:
-        return self.model.state_dict()
-
-    def load_state_dict(self, state_dict: Dict[str, torch.Tensor]):
-        self.model.load_state_dict(state_dict)
-
     def validate_context(self):
         super().validate_context()
         assert self.train_loader and len(self.train_loader) > 0, 'failed to load train data'
@@ -509,7 +456,7 @@ class DemoDP(DPFedAvgScheduler):
         loss.backward()
         self.optimizer.step()
 
-    def test(self):
+    def run_test(self):
         self.model.eval()
         test_loss = 0
         correct = 0
@@ -549,38 +496,28 @@ def get_scheduler(mode: str = VANILLA) -> FedAvgScheduler:
         os.remove(pickle_file)
 
     if mode == VANILLA:
-        scheduler = DemoAvg(min_clients=3,
-                            max_clients=3,
-                            name='demo_fed_avg',
-                            max_rounds=5,
+        scheduler = DemoAvg(max_rounds=5,
                             log_rounds=1,
                             calculation_timeout=60,
                             involve_aggregator=True)
 
     elif mode == SGD:
-        scheduler = DemoSGD(min_clients=3,
-                            name='demo_fed_sgd',
-                            max_rounds=50,
+        scheduler = DemoSGD(max_rounds=200,
                             log_rounds=1,
                             calculation_timeout=60)
 
     elif mode == DP:
-        scheduler = DemoDP(min_clients=2,
-                           w_cap=20000,
+        scheduler = DemoDP(w_cap=20000,
                            q=0.9,
                            S=1,
                            z=0.1,
-                           name='demo_dp_fed_avg',
                            max_rounds=5,
                            log_rounds=1,
                            calculation_timeout=60,
                            involve_aggregator=True)
 
     elif mode == SECURE:
-        scheduler = DemoSecure(min_clients=3,
-                               max_clients=3,
-                               t=2,
-                               name='demo_secure_avg',
+        scheduler = DemoSecure(t=2,
                                max_rounds=5,
                                log_rounds=1,
                                calculation_timeout=120)
@@ -588,12 +525,9 @@ def get_scheduler(mode: str = VANILLA) -> FedAvgScheduler:
     elif mode == FED_IRM:
         root_dir = '/data/alphamed/alphamed-dataset/tutorials/FedIRM/'
         scheduler = DemoFedIRM(
-            min_clients=4,
-            max_clients=4,
             root_path=os.path.join(root_dir, 'gtr21/ISIN-2018/train_image_224'),
             csv_file_train=os.path.join(root_dir, 'train.csv'),
             csv_file_test=os.path.join(root_dir, 'test.csv'),
-            name='demo_Fed_IRM',
             max_rounds=50,
             log_rounds=5,
             calculation_timeout=3600,
