@@ -23,7 +23,5 @@ args = parser.parse_args()
 task_id = get_task_id()
 scheduler = get_scheduler(mode=args.mode)
 logger.debug(f'{type(scheduler)=}')
-scheduler._setup_context(id=DATA_OWNER_5_ID, task_id=task_id)
-scheduler.data_channel._ports = [i for i in range(21000, 21010)]
 logger.info(f'run data owner 5 in {args.mode} mode: {task_id=}')
-scheduler._launch_process()
+scheduler._run(id=DATA_OWNER_5_ID, task_id=task_id)
