@@ -6,8 +6,7 @@ from abc import ABC
 from dataclasses import dataclass
 from typing import List
 
-from ..contractor import (ApplySharedFileSendingDataEvent,
-                          AutoTaskMessageContractor, ContractEvent,
+from ..contractor import (AutoTaskMessageContractor, ContractEvent,
                           TaskMessageContractor, TaskMessageEventFactory)
 
 
@@ -182,12 +181,6 @@ class ResetRoundEvent(ContractEvent):
         return ResetRoundEvent()
 
 
-# define some more friendly alias
-SynchronizeAggregatorContextEvent = ApplySharedFileSendingDataEvent
-DistributeParametersEvent = ApplySharedFileSendingDataEvent
-UploadTrainingResultsEvent = ApplySharedFileSendingDataEvent
-
-
 class FedAvgEventFactory(TaskMessageEventFactory):
 
     _CLASS_MAP = {
