@@ -609,7 +609,11 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
         )
         for _source, _result in training_results.items():
             buffer = io.BytesIO(_result)
-            _new_state_dict = torch.load(buffer)
+            try:
+                _new_state_dict = torch.load(buffer)
+            except RuntimeError:
+                # to deal with GPU parameters on a CPU machine  TODO improve me
+                _new_state_dict = torch.load(buffer, map_location=torch.device('cpu'))
             for _key in accum_result.keys():
                 accum_result[_key].add_(_new_state_dict[_key])
             result_count += 1
@@ -725,7 +729,11 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
             source=self._aggregator
         )
         buffer = io.BytesIO(parameters)
-        new_state_dict = torch.load(buffer)
+        try:
+            new_state_dict = torch.load(buffer)
+        except RuntimeError:
+            # to deal with GPU parameters on a CPU machine  TODO improve me
+            new_state_dict = torch.load(buffer, map_location=torch.device('cpu'))
         self.load_state_dict(new_state_dict)
         self.push_log('Successfully received latest parameters.')
 
