@@ -744,16 +744,17 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
         self.push_log(f'Closing task {self.task_id} ...')
 
         self._switch_status(self._FINISHING)
-        self.contractor.finish_task(is_succ=is_succ)
         if is_succ:
             report_file_path, model_file_path = self._prepare_task_output()
             self.contractor.upload_task_achivement(aggregator=self.id,
                                                    report_file=report_file_path,
                                                    model_file=model_file_path)
+            self.contractor.finish_task(is_succ=True)
             self._wait_for_all_complete()
             self.contractor.notify_task_completion(result=True)
             self.push_log(f'Task {self.task_id} complete. Byebye!')
         else:
+            self.contractor.finish_task(is_succ=False)
             self.push_log(f'Task {self.task_id} failed. Byebye!')
 
     def _prepare_task_output(self) -> Tuple[str, str]:
